Struct CompactMonth

pub struct CompactMonth(/* private fields */);
A compact representation of included days for a month, using a u32-based bit array.

Implementations

Source

impl CompactMonth

pub fn insert(&mut self, day: u32) -> bool

Include a day in this month. Return false if it was already included.

use compact_calendar::CompactMonth;

let mut month = CompactMonth::default();
month.insert(2);
month.insert(2);
month.insert(19);
assert_eq!(month.count(), 2);
pub fn contains(self, day: u32) -> bool

Check if this month includes the given day.

use compact_calendar::CompactMonth;

let mut month = CompactMonth::default();
month.insert(1);
month.insert(18);

assert!(month.contains(1));
assert!(month.contains(18));
assert!(!month.contains(5));
pub fn iter(self) -> impl Iterator<Item = u32>

Iterate over the days included in this month.

use compact_calendar::CompactMonth;

let mut month = CompactMonth::default();
month.insert(18);
month.insert(1);

let days: Vec<u32> = month.iter().collect();
assert_eq!(days, [1, 18])
pub fn first(self) -> Option<u32>

Get the first day included in this month if it is not empty.

use compact_calendar::CompactMonth;

let mut month = CompactMonth::default();
assert_eq!(month.first(), None);

month.insert(31);
assert_eq!(month.first(), Some(31));

month.insert(8);
assert_eq!(month.first(), Some(8));
pub fn first_after(self, day: u32) -> Option<u32>

Get the first day included in this month that follows the input day, if such a day exists.

use compact_calendar::CompactMonth;

let mut month = CompactMonth::default();
month.insert(4);
month.insert(17);

assert_eq!(month.first_after(2), Some(4));
assert_eq!(month.first_after(4), Some(17));
assert_eq!(month.first_after(17), None);
pub fn count(self) -> u32

Count number of days included for this month.

use compact_calendar::CompactMonth;

let mut month = CompactMonth::default();
month.insert(26);
month.insert(3);
assert_eq!(month.count(), 2);
pub fn serialize(self, writer: impl Write) -> Result<()>

Serialize this month into a writer.

use compact_calendar::CompactMonth;

let mut month = CompactMonth::default();

let mut buf1 = Vec::new();
month.insert(31);
month.serialize(&mut buf1).unwrap();

let mut buf2 = Vec::new();
month.insert(1);
month.serialize(&mut buf2).unwrap();

assert_ne!(buf1, buf2);
pub fn deserialize(reader: impl Read) -> Result<Self>

Deserialize a month from a reader.

use compact_calendar::CompactMonth;

let mut month1 = CompactMonth::default();
month1.insert(30);
month1.insert(2);

let mut buf = Vec::new();
month1.serialize(&mut buf).unwrap();

let month2 = CompactMonth::deserialize(buf.as_slice()).unwrap();
assert_eq!(month1, month2);