pub struct CompactYear(_);
A compact representation of included days for a year, using a collection of u32-based bit array.

Implementations

Create a new year that does not include any day.

use compact_calendar::CompactYear;

let year = CompactYear::new();
assert_eq!(year.count(), 0);

Include a day in this year.

use compact_calendar::CompactYear;

let mut year = CompactYear::new();
year.insert(11, 3);
year.insert(11, 3);
year.insert(1, 25);
assert_eq!(year.count(), 2);

Check if this year includes the given day.

use compact_calendar::CompactYear;

let mut year = CompactYear::new();
year.insert(3, 1);
year.insert(9, 5);

assert!(year.contains(3, 1));
assert!(year.contains(9, 5));
assert!(!year.contains(7, 14));

Iterate over the days included in this year.

use compact_calendar::CompactYear;

let mut year = CompactYear::new();
year.insert(9, 5);
year.insert(3, 1);

let days: Vec<_> = year.iter().collect();
assert_eq!(days, [(3, 1), (9, 5)])

Get the first day included in this year if it is not empty.

use compact_calendar::CompactYear;

let mut year = CompactYear::new();
assert_eq!(year.first(), None);

year.insert(12, 31);
assert_eq!(year.first(), Some((12, 31)));

year.insert(5, 8);
assert_eq!(year.first(), Some((5, 8)));

Get the first day included in this year that follows the input day, if such a day exists.

use compact_calendar::CompactYear;

let mut year = CompactYear::new();
year.insert(3, 15);
year.insert(10, 9);
year.insert(2, 7);

assert_eq!(year.first_after(2, 2), Some((2, 7)));
assert_eq!(year.first_after(2, 7), Some((3, 15)));
assert_eq!(year.first_after(11, 1), None);

Count number of days included for this year.

use compact_calendar::CompactYear;

let mut year = CompactYear::new();
year.insert(11, 3);
year.insert(4, 28);
assert_eq!(year.count(), 2);

Serialize this year into a writer.

use compact_calendar::CompactYear;

let mut year = CompactYear::new();

let mut buf1 = Vec::new();
year.insert(11, 3);
year.serialize(&mut buf1).unwrap();

let mut buf2 = Vec::new();
year.insert(4, 28);
year.serialize(&mut buf2).unwrap();

assert_ne!(buf1, buf2);

Deserialize a year from a reader.

use compact_calendar::CompactYear;

let mut year1 = CompactYear::new();
year1.insert(11, 3);
year1.insert(4, 28);

let mut buf = Vec::new();
year1.serialize(&mut buf).unwrap();

let year2 = CompactYear::deserialize(buf.as_slice()).unwrap();
assert_eq!(year1, year2);