pub struct CompactCalendar { /* private fields */ }
A compact representation of included days in a range of years, using u32-based bit arrays.

Implementations

Create a new year that does not include any day but has the capacity to add any new day in the range of [first_year, last_year].

use compact_calendar::CompactCalendar;
use chrono::NaiveDate;

let day1 = NaiveDate::from_ymd(2013, 11, 3);
let day2 = NaiveDate::from_ymd(2022, 3, 5);
let day3 = NaiveDate::from_ymd(2055, 7, 5);

let mut cal = CompactCalendar::new(2020, 2050);
assert!(!cal.insert(day1));
assert!(cal.insert(day2));
assert!(!cal.insert(day3));
assert_eq!(cal.count(), 1);

Create a new calendar year that does not include any day and does not have the capacity to add any.

use compact_calendar::CompactCalendar;
use chrono::NaiveDate;

let mut cal = CompactCalendar::empty();
assert!(!cal.insert(NaiveDate::from_ymd(2013, 11, 3)));
assert_eq!(cal.count(), 0);

Get a reference to the year containing give date.

use compact_calendar::CompactCalendar;
use chrono::NaiveDate;

let day1 = NaiveDate::from_ymd(2013, 11, 3);
let day2 = NaiveDate::from_ymd(2055, 3, 5);

let mut cal = CompactCalendar::new(2000, 2050);
cal.insert(day1);

assert!(cal.year_for(day1).unwrap().contains(11, 3));
assert!(cal.year_for(day2).is_none());

Get a mutable reference to the year containing give date.

use compact_calendar::CompactCalendar;
use chrono::NaiveDate;

let day1 = NaiveDate::from_ymd(2013, 11, 3);
let day2 = NaiveDate::from_ymd(2022, 3, 5);
let day3 = NaiveDate::from_ymd(2055, 7, 5);

let mut cal = CompactCalendar::new(2000, 2050);
assert!(cal.year_for_mut(day3).is_none());

cal.insert(day1);
assert!(cal.year_for_mut(day1).unwrap().contains(11, 3));

cal.year_for_mut(day2).unwrap().insert(3, 5);
assert!(cal.contains(day2));

Include a day in this calendar. Return false if the given day was not inserted because it does not belong to the year range of this calendar.

use compact_calendar::CompactCalendar;
use chrono::NaiveDate;

let day1 = NaiveDate::from_ymd(2013, 11, 3);
let day2 = NaiveDate::from_ymd(2022, 3, 5);
let day3 = NaiveDate::from_ymd(2055, 9, 7);

let mut cal = CompactCalendar::new(2000, 2050);
assert!(cal.insert(day1));
assert!(cal.insert(day1));
assert!(cal.insert(day2));
assert_eq!(cal.count(), 2);

assert!(!cal.insert(day3));
assert_eq!(cal.count(), 2);

Check if this calendar includes the given day.

use compact_calendar::CompactCalendar;
use chrono::NaiveDate;

let day1 = NaiveDate::from_ymd(2013, 11, 3);
let day2 = NaiveDate::from_ymd(2022, 3, 5);
let day3 = NaiveDate::from_ymd(2022, 8, 12);

let mut cal = CompactCalendar::new(2000, 2050);
cal.insert(day1);
cal.insert(day2);

assert!(cal.contains(day1));
assert!(cal.contains(day2));
assert!(!cal.contains(day3));

Iterate over the days included in this calendar.

use compact_calendar::CompactCalendar;
use chrono::NaiveDate;

let day1 = NaiveDate::from_ymd(2013, 11, 3);
let day2 = NaiveDate::from_ymd(2022, 3, 5);
let day3 = NaiveDate::from_ymd(2022, 8, 12);

let mut cal = CompactCalendar::new(2000, 2050);
cal.insert(day3);
cal.insert(day1);
cal.insert(day2);

let days: Vec<_> = cal.iter().collect();
assert_eq!(days, [day1, day2, day3])

Get the first day included in this calendar that follows the input day, if such a day exists.

use compact_calendar::CompactCalendar;
use chrono::NaiveDate;

let day0 = NaiveDate::from_ymd(2010, 1, 1);
let day1 = NaiveDate::from_ymd(2013, 11, 3);
let day2 = NaiveDate::from_ymd(2022, 3, 5);
let day3 = NaiveDate::from_ymd(2022, 8, 12);

let mut cal = CompactCalendar::new(2000, 2050);
cal.insert(day1);
cal.insert(day2);
cal.insert(day3);

assert_eq!(cal.first_after(day0), Some(day1));
assert_eq!(cal.first_after(day2), Some(day3));
assert_eq!(cal.first_after(day3), None);

Count number of days included for this calendar.

use compact_calendar::CompactCalendar;
use chrono::NaiveDate;

let mut cal = CompactCalendar::new(2000, 2050);
cal.insert(NaiveDate::from_ymd(2022, 8, 12));
cal.insert(NaiveDate::from_ymd(2022, 3, 5));
assert_eq!(cal.count(), 2);

Serialize this calendar into a writer.

use compact_calendar::CompactCalendar;
use chrono::NaiveDate;

let mut cal = CompactCalendar::new(2000, 2050);

let mut buf1 = Vec::new();
cal.insert(NaiveDate::from_ymd(2022, 8, 12));
cal.serialize(&mut buf1).unwrap();

let mut buf2 = Vec::new();
cal.insert(NaiveDate::from_ymd(2022, 3, 5));
cal.serialize(&mut buf2).unwrap();

assert_ne!(buf1, buf2);

Deserialize a calendar from a reader.

use compact_calendar::CompactCalendar;
use chrono::NaiveDate;

let mut cal1 = CompactCalendar::new(2000, 2050);
cal1.insert(NaiveDate::from_ymd(2022, 8, 12));
cal1.insert(NaiveDate::from_ymd(2022, 3, 5));

let mut buf = Vec::new();
cal1.serialize(&mut buf).unwrap();

let cal2 = CompactCalendar::deserialize(buf.as_slice()).unwrap();
assert_eq!(cal1, cal2);